#
# spec file for package wxhexeditor
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%bcond_with gcc6
%define _name   wxHexEditor
%define _rev    3f34976552e4d8f62c260b60825b7d0faf064ff2

Name:           wxhexeditor
Version:        0.24
Release:        3.15
Summary:        A free HEX editor / disk editor
# Program is statically linked to udis86 which is BSD-2-Clause
License:        GPL-2.0-only
Group:          Development/Tools/Other
URL:            https://github.com/EUA/wxHexEditor
Source:         https://github.com/EUA/wxHexEditor/archive/v%{version}.tar.gz#/%{_name}-%{version}.tar.gz
# PATCH-FIX-OPENSUSE wxhexeditor-0.23-mhash.patch lazy.kent@opensuse.org -- Use system mhash library.
Patch0:         %{name}-0.23-mhash.patch
# PATCH-FIX-OPENSUSE wxhexeditor-remove-debug.patch zaitor@opensuse.org -- Remove debug msg that include nonsense.
Patch1:         wxhexeditor-remove-debug.patch
# PATCH-FIX-UPSTREAM wxhexeditor-fixdesktopfile.patch davejplater@gmail.com -- Fix desktop file
Patch2:         wxhexeditor-fixdesktopfile.patch
# PATCH-FIX-UPSTREAM - https://github.com/EUA/wxHexEditor/issues/90
Patch3:         wxhexeditor-fix-arm.patch
# PATCH-FEATURE-UPSTREAM - https://github.com/EUA/wxHexEditor/pull/173
Patch4:         wxhexeditor-appdata.patch
%if %{with gcc6}
%if 0%{?sle_version} >= 120200
#!BuildIgnore:  libgcc_s1
BuildRequires:  cpp6
BuildRequires:  gcc6
BuildRequires:  gcc6-c++
%endif
%endif
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  gcc-c++
BuildRequires:  libtool
BuildRequires:  mhash-devel
BuildRequires:  pkg-config
BuildRequires:  update-desktop-files
BuildRequires:  wxWidgets-3_0-devel
Recommends:     %{name}-lang

%description
wxHexEditor is a hex editor that is capable of handling very large
files. It supports files up to 2^64 bytes. It can also act as a
disk editor.
Features:
 * Small footprint on RAM;
 * Raw Disk Access (on POSIX systems);
 * Does not create temporary files.

%lang_package

%prep
%setup -q -n %{_name}-%{version}
rm -rf mhash
%patch0 -p0
%patch1 -p0
%patch2
%patch3 -p1
%patch4 -p1
chmod -x docs/*
cp -v udis86/LICENSE LICENSE-udis86
cp -v docs/GPL.txt .

%build
%if %{with gcc6}
%if 0%{?sle_version} >= 120200
export CC=gcc-6
export CPP=cpp-6
export CXX=g++-6
%endif
%endif
make %{?_smp_mflags} V=1 \
%if 0%{?suse_version} > 1320
  PYTHON='%{_bindir}/python3' \
%endif
  CFLAGS='%{optflags}'   \
  CXXFLAGS='%{optflags}'

%install
%make_install PREFIX=%{_prefix}
%find_lang %{_name} %{?no_lang_C}
install resources/wxhexeditor.xml -Dm0644 %{buildroot}%{_datadir}/metainfo/wxhexeditor.xml

%post
%desktop_database_post

%postun
%desktop_database_postun

%files
%defattr(-,root,root)
%doc docs/Change.log README.md
%license GPL.txt LICENSE-udis86
%{_bindir}/%{_name}
%{_datadir}/applications/%{_name}.desktop
%{_datadir}/pixmaps/%{_name}.png
%{_datadir}/metainfo/wxhexeditor.xml

%files lang -f %{_name}.lang
%defattr(-,root,root)

%changelog
* Mon Nov 16 2020 Matthias Mailänder <mailaender@opensuse.org>
- Add wxhexeditor-appdata.patch for https://en.opensuse.org/openSUSE:AppStore
* Wed Oct 14 2020 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Backport patch to fix build on Arm:
  * wxhexeditor-fix-arm.patch
* Sun Feb  4 2018 davejplater@gmail.com
- Update to release 0.24 and modify wxhexeditor-0.23-mhash.patch.
- Use %%license on license files.
- Upstream changes:
  * Fixed many critical bugs and assertions. (Thanks Mikhail Kasimov
  for Beta testing.)
  * Fixed many compiler warnings.
  * Added Wiki option to Help.
  * Fixed language not supported error for English.
* Fri Dec 29 2017 davejplater@gmail.com
- Make description relevant to the package.
* Thu Dec 28 2017 jengelh@inai.de
- Trim filler wording from description.
* Sat Dec 23 2017 davejplater@gmail.com
- Fix Factory build by explicitly specifying python3 binary for
  udis86 build.
- Update to 0.23+git20170810
- Upstream changes:
  Fixed TAG deletion behaviour while tag not selected.
  Implemented tags redo/undo support.
  Fixed part of #67, SEGV due Tags.
  Fixed Forward Search SEGV. Fixed recent mem leak patch.
  Delete existing buffers on allocation failure.
* Fri Mar 24 2017 davejplater@gmail.com
- Update to 0.23+git20170316
- Upstream changes:
  Fixed file cut/deletion tag issues. #67
* Sun Mar 12 2017 davejplater@gmail.com
- Update to 0.23+git20170312
- Upstream changes:
  Fixed MinGW32 compatibility.
  Fixed GIANT file size detection. (Can open /proc/kcore now)
* Tue Mar  7 2017 davejplater@gmail.com
- Update to 0.23+git20170307
- Upstream changes:
  Fixed read mode cosmetic issues and add some compare mode
  restrictions. #59
  Removed right click into search and compare panels. #48
* Mon Mar  6 2017 davejplater@gmail.com
- Update to 0.23+git20170306
- Upstream changes:
  Fixed Assertion with zero sized files. #56
  Fixed 0 sized file GoTo seek error #56
  Fixed some operations with 0 sized files #56
* Tue Feb 28 2017 davejplater@gmail.com
- Update to 0.23+git20170228
- Upstream changes:
  Added selection after paste for #44
  Fixed deleted TAG live on taglist error.
* Sun Feb 26 2017 davejplater@gmail.com
- Update to 0.23+git20170226
- Upstream changes:
  Fixed typo & allow find dialog to hide.
  Fixed last comma with CopyAs Special Hex 0x with ","
  Fixed block deletion issue #50
* Fri Feb 24 2017 davejplater@gmail.com
- Update to 0.23+git20170224 to fix reopened boo#1022460
- Upstream changes:
  Implemented Portable mode.
  Replaced SF.net links with wxHexEditor.org
  Fixed cosmetic typo
  Fixed Find Backward Wraparound SEGV #48
  Added support for Paste Hex with "\x00" notation. #44
  Fixed FindAll double find cosmetic issue.
* Thu Feb 23 2017 davejplater@gmail.com
- Update to 0.23+git20170223 to fix i586 build.
- Upstream changes:
  Fixed find result for zero offset location bug #46.
  Fixed non-SSE2 environment build.
  Removed ":" from tag dialogs.
* Tue Feb 21 2017 davejplater@gmail.com
- Update to 0.23+git20170221 to fix reopened boo#1022460
- Added wxhexeditor-fixdesktopfile.patch to fix desktop file.
- Upstream changes:
    Added Cancel button to Tag Edit Dialog
    Fixed FileSystemWatcher : operational right now.
    Fixed more FileSystemWatcher issues.
    Fixed FileWatcher for files open via CLI arg.
    Replaced nullptr with old NULL for compatibility.
    Fixed FindAll SEG fault and double find issues.
    Fixed locale file.
    Fixed thread kill on file close.
    Fixed Disk Image Tools cosmetics
    Refactored FIND functions with SSE2
* Fri Feb  3 2017 davejplater@gmail.com
- Update to git version 0.23+git20161226 (boo#1022460):
  * See https://github.com/EUA/wxHexEditor/commits/master
- Removed wxhexeditor-0.23-func-return.patch: fixed upstream.
  Rebased wxhexeditor-0.23-mhash.patch and
  wxhexeditor-remove-debug.patch.
* Sat Jan  7 2017 zaitor@opensuse.org
- Add wxhexeditor-remove-debug.patch: Remove some debug printed on
  stdout, patch taken from debian.
* Fri Nov 25 2016 lazy.kent@opensuse.org
- Fix "find requires" (remove %%wx_requires) (boo#1022637).
* Sat Aug 20 2016 jengelh@inai.de
- Build against wxWidgets 3
* Wed Dec 10 2014 sor.alexei@meowr.ru
- Update to 0.23:
  * Added many languages.
  * Fixed many bugs that leads to crash and memory leaks.
  * Implemented prefetched functions (SSD buster).
  * Fixed some cosmetic errors.
  * Fixed C::B compilation for all operating systems.
  * Added Sorted Tag Saving / Loading.
  * Fixed Injection function.
  * Implemented file change detection reload (on wxWidgets > 2.9).
  * Implemented file compare connector to scroll 2 files at once.
  * Added remember last panel states.
  * Fixed TagEdit enabling code for addesses > 0xFFFFFFFFh.
  * Added MultiSearchAtBinary function, allows faster search on
    FindAll.
  * Fixed logical sectors start. Now starts from 0 instead of 1.
  * Added AutoShowTag option to preferences menu.
  * Added auto tag panel popup with Process RAM open.
  * Fixed Process RAM seeking.
  * Added Report a Bug & Donation menu items.
  * "Find Some Bytes" button doesn't close find dialog anymore.
- Add missing %%{optflags} and wxhexeditor-0.23-func-return.patch.
- Replace wxhexeditor-0.22-mhash.patch with
  wxhexeditor-0.23-mhash.patch (rebased).
* Thu Oct  2 2014 sor.alexei@meowr.ru
- Add %%desktop_database_post{,un}.
- Minor spec cleanup.
* Sat Jul 26 2014 lazy.kent@opensuse.org
- Add wxhexeditor-0.22-mhash.patch: use system mhash library.
- BuildRequires: mhash-devel.
- Use wxWidgets defines.
- BuildRequires: wxWidgets-wxcontainer-devel -> wxWidgets-devel.
- Remove unused BuildRequires: fdupes.
- Install docs.
* Tue Jul 15 2014 sor.alexei@meowr.ru
- Initial build.
